@@ -14,7 +14,7 @@ use base qw(Verilog::Netlist::Subclass);
 use strict;
 use vars qw($Debug $Verbose $VERSION);
 
-$VERSION = '3.251';
+$VERSION = '3.312';
 
 ######################################################################
 #### Error Handling
@@ -38,8 +38,10 @@ sub new {
 		options => undef,	# Usually pointer to Verilog::Getopt
 		symbol_table => [],	# Symbol table for Verilog::Parser
  		preproc => 'Verilog::Preproc',
+		remove_defines_without_tick => 0,   # Overriden in SystemC::Netlist
 		#include_open_nonfatal => 0,
 		#keep_comments => 0,
+		#synthesis => 0,
 		use_vars => 1,
 		_libraries_done => {},
 		_need_link => [],	# Objects we need to ->link
@@ -151,11 +153,14 @@ sub remove_defines {
     my $self = shift;
     my $sym = shift;
     # This function is HOT
+    my $xsym = $sym;
     # We only remove defines one level deep, for historical reasons.
-    # We don't require a ` as SystemC also uses this function and doesn't use `.
-    (my $xsym = $sym) =~ s/^\`//;
-    my $val = $self->defvalue_nowarn($xsym);  #Undef if not found
-    $sym = $val if defined $val;
+    # We optionally don't require a ` as SystemC also uses this function and doesn't use `.
+    if ($self->{remove_defines_without_tick} || $xsym =~ /^\`/) {
+	$xsym =~ s/^\`//;
+	my $val = $self->defvalue_nowarn($xsym);  #Undef if not found
+	return $val if defined $val;
+    }
     return $sym;
 }
 
@@ -491,11 +496,6 @@ undefined modules through the "options" object.
 Indicates that modules that referenced but not found should be ignored,
 rather than causing an error message.
 
-=item lint_pin_interconnect => $true_or_false
-
-Indicates that lint should Interconnect information is not needed, do not read it, nor report lint
-related pin warnings.  Greatly improves performance.
-
 =item logger => object
 
 Specify a message handler object to be used for error handling, this class
@@ -512,6 +512,14 @@ files.
 
 The name of the preprocessor class. Defaults to "Verilog::Preproc".
 
+=item synthesis => $true_or_false
+
+With synthesis set, define SYNTHESIS, and ignore text bewteen "ambit",
+"pragma", "synopsys" or "synthesis" translate_off and translate_on meta
+comments.  Note using metacomments is discouraged as they have led to
+silicon bugs (versus ifdef SYNTHESIS); see
+L<http://www.veripool.org/papers/TenIPEdits_SNUGBos07_paper.pdf>.
+
 =item use_vars => $true_or_false
 
 Indicates that signals, variables, and pin interconnect information is
@@ -647,7 +655,8 @@ lookup.  Return undef if not found.
 
 =item $self->verilog_text
 
-Returns verilog code which represents the netlist.
+Returns verilog code which represents the netlist.  The netlist must be
+already ->link'ed for this to work correctly.
 
 =back
 
@@ -664,7 +673,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2010 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2011 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
