@@ -16,7 +16,7 @@ use strict;
 @ISA = qw(Verilog::Netlist::Pin::Struct
 	Verilog::Netlist::Subclass);
 
-$VERSION = '3.305';
+$VERSION = '3.312';
 
 structs('new',
 	'Verilog::Netlist::Pin::Struct'
@@ -44,6 +44,11 @@ structs('new',
 
 sub delete {
     my $self = shift;
+    if ($self->net && $self->port) {
+	$self->net->_used_in_dec()    if ($self->port->direction eq 'in');
+	$self->net->_used_out_dec()   if ($self->port->direction eq 'out');
+	$self->net->_used_inout_dec() if ($self->port->direction eq 'inout');
+    }
     my $h = $self->cell->_pins;
     delete $h->{$self->name};
     return undef;
@@ -257,7 +262,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2010 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2011 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
