@@ -14,19 +14,23 @@ use base qw(Verilog::Parser);
 ######################################################################
 #### Configuration Section
 
-$VERSION = '3.305';
+$VERSION = '3.312';
 
 our @_Callback_Names = qw(
   attribute
+  class
   contassign
+  covergroup
   defparam
   endcell
+  endclass
+  endgroup
   endinterface
   endmodport
-  endtaskfunc
   endmodule
   endpackage
   endprogram
+  endtaskfunc
   function
   import
   instant
@@ -101,16 +105,37 @@ sub contassign {
     my $rhs = shift;
 }
 
+sub class {
+    my $self = shift;
+    my $keyword = shift;
+    my $name = shift;
+    my $virtual = shift;
+}
+
+sub covergroup {
+    my $self = shift;
+    my $keyword = shift;
+    my $name = shift;
+}
+
 sub defparam {
     my $self = shift;
     my $lhs = shift;
     my $rhs = shift;
 }
 
+sub endclass {
+    my $self = shift;
+}
+
 sub endcell {
     my $self = shift;
 }
 
+sub endgroup {
+    my $self = shift;
+}
+
 sub endinterface {
     my $self = shift;
 }
@@ -288,6 +313,14 @@ of each comment line (C<//key rest> to end of line) or comment block
 (C</*key rest */).  It calls C<$self->attribute( meta_text )>
 if the first word has a true value in hash C<$self->metacomment>.
 
+=item $self->class ( $token, $name, $virtual )
+
+This method is called at a class.
+
+=item $self->covergroup ( $token, $name )
+
+This method is called at a covergroup.
+
 =item $self->contassign ( $token, $lhs, $rhs )
 
 This method is called at a continuous "assign" keyword, with the left and
@@ -305,11 +338,21 @@ part of the assignment.
 This method is called at the end of defining a cell. It is useful for
 writing clean up routines.
 
+=item $self->endgroup ( $token )
+
+This method is called at the end of defining a covergroup. It is useful for
+writing clean up routines.
+
 =item $self->endinterface ( $token )
 
 This method is called at a endinterface keyword. It is useful for writing
 clean up routines.
 
+=item $self->endclass ( $token )
+
+This method is called at a endclass keyword.  It is useful for writing
+clean up routines.
+
 =item $self->endtaskfunc ( $token )
 
 This method is called at a endfunction or endtask keyword.  It is useful
@@ -474,7 +517,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2010 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2011 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
